@@ -2,45 +2,14 @@ package Apache2::GeoIP;
 
 use strict;
 use warnings;
-use base qw(Exporter);
-use vars qw($VERSION @EXPORT_OK);
+use vars qw($VERSION);
+require DynaLoader;
 
-$VERSION = '1.99_01';
-@EXPORT_OK = qw(find_addr);
+@Apache2::GeoIP::ISA = qw(DynaLoader);
 
-sub get_remote_ip {
-  my ($r) = @_;
-  if ($r->can('useragent_ip')) {
-    return $r->useragent_ip;
-  } else {
-    return $r->connection->remote_ip;
-  }
-}
-
-sub find_addr {
-  my ($r, $xforwardedfor) = @_;
-  my $host;
-  if (defined $xforwardedfor) {
-    my $ReIpNum = qr{([01]?\d\d?|2[0-4]\d|25[0-5])};
-    my $ReIpAddr = qr{^$ReIpNum\.$ReIpNum\.$ReIpNum\.$ReIpNum$};
-    $host =  $r->headers_in->get('X-Forwarded-For') || get_remote_ip($r);
-    if ($host =~ /,/) {
-      my @a = split /\s*,\s*/, $host;
-      for my $i (0 .. $#a) {
-          if ($a[$i] =~ /$ReIpAddr/ and $a[$i] ne '127.0.0.1') {
-              $host = $a[$i];
-              last;
-          }
-      }
-      $host = '127.0.0.1' if $host =~ /,/;
-    }
-  }
-  else {
-    $host = get_remote_ip($r);
-  }
-  return $host;
-}
+$VERSION = '1.62';
 
+__PACKAGE__->bootstrap($VERSION);
 
 1;
 
